==> seedsui-react-5.8.25.tgz: package/lib/DatePicker/RangeMain/SelectorMain/CustomModal/CustomDates.js <==
import React from 'react';
import locale from "./../../../../locale";
// 测试使用
// import locale from 'seedsui-react/lib/locale'

import Combo from "./../../../Combo";

// 自定义日期选择弹窗: 两框选择
export default function CustomDates(_ref) {
  var portal = _ref.portal,
    type = _ref.type,
    allowClear = _ref.allowClear,
    value = _ref.value,
    _onBeforeChange = _ref.onBeforeChange,
    _onChange = _ref.onChange,
    onError = _ref.onError,
    DatePickerModalProps = _ref.DatePickerModalProps;
  // 开始和结束日期
  var startDate = Array.isArray(value) && value[0] instanceof Date ? value[0] : null;
  var endDate = Array.isArray(value) && value[1] instanceof Date ? value[1] : null;
  return /*#__PURE__*/React.createElement("div", {
    className: "datepicker-rangemain-custom"
  }, /*#__PURE__*/React.createElement(Combo, {
    portal: portal,
    ModalProps: DatePickerModalProps,
    type: type,
    value: startDate
    // max={Array.isArray(value) && value.length === 2 ? value[1] : undefined}
    // onError={onError}
    ,
    onBeforeChange: function onBeforeChange(argStartDate) {
      var newStartDate = argStartDate || null;
      if (_onBeforeChange) {
        return _onBeforeChange(newStartDate || endDate ? [newStartDate, endDate] : null);
      }
    },
    onChange: function onChange(argStartDate) {
      var newStartDate = argStartDate || null;
      if (_onChange) _onChange(newStartDate || endDate ? [newStartDate, endDate] : null);
    },
    placeholder: locale('请选择', 'ZKGJ001848'),
    allowClear: allowClear,
    ricon: /*#__PURE__*/React.createElement("i", {
      className: "ricon icon shape-arrow-right sm",
      style: {
        marginRight: '4px'
      }
    })
  }), "\u2014", /*#__PURE__*/React.createElement(Combo, {
    portal: portal,
    ModalProps: DatePickerModalProps,
    type: type,
    value: endDate
    // min={Array.isArray(value) && value.length === 2 ? value[0] : undefined}
    // onError={onError}
    ,
    onBeforeChange: function onBeforeChange(argEndDate) {
      var newEndDate = argEndDate || null;
      if (_onBeforeChange) {
        return _onBeforeChange(startDate || newEndDate ? [startDate, newEndDate] : null);
      }
    },
    onChange: function onChange(argEndDate) {
      var newEndDate = argEndDate || null;
      if (_onChange) _onChange(startDate || newEndDate ? [startDate, newEndDate] : null);
    },
    placeholder: locale('请选择', 'ZKGJ001848'),
    allowClear: allowClear,
    ricon: /*#__PURE__*/React.createElement("i", {
      className: "ricon icon shape-arrow-right sm",
      style: {
        marginRight: '4px'
      }
    })
  }));
}

==> seedsui-react-5.8.44.tgz: package/lib/DatePicker/RangeMain/SelectorMain/CustomModal/CustomDates.js <==
import React from 'react';
import locale from "./../../../../locale";
// 测试使用
// import locale from 'seedsui-react/lib/locale'

import Combo from "./../../../Combo";

// 自定义日期选择弹窗: 两框选择
export default function CustomDates(_ref) {
  var portal = _ref.portal,
    type = _ref.type,
    disabledStart = _ref.disabledStart,
    disabledEnd = _ref.disabledEnd,
    allowClear = _ref.allowClear,
    value = _ref.value,
    _onBeforeChange = _ref.onBeforeChange,
    _onChange = _ref.onChange,
    onError = _ref.onError,
    DatePickerModalProps = _ref.DatePickerModalProps;
  // 开始和结束日期
  var startDate = Array.isArray(value) && value[0] instanceof Date ? value[0] : null;
  var endDate = Array.isArray(value) && value[1] instanceof Date ? value[1] : null;
  return /*#__PURE__*/React.createElement("div", {
    className: "datepicker-rangemain-custom"
  }, /*#__PURE__*/React.createElement(Combo, {
    portal: portal,
    ModalProps: DatePickerModalProps,
    type: type,
    value: startDate,
    disabled: disabledStart
    // max={Array.isArray(value) && value.length === 2 ? value[1] : undefined}
    // onError={onError}
    ,
    onBeforeChange: function onBeforeChange(argStartDate) {
      var newStartDate = argStartDate || null;
      if (_onBeforeChange) {
        return _onBeforeChange(newStartDate || endDate ? [newStartDate, endDate] : null);
      }
    },
    onChange: function onChange(argStartDate) {
      var newStartDate = argStartDate || null;
      if (_onChange) _onChange(newStartDate || endDate ? [newStartDate, endDate] : null);
    },
    placeholder: locale('请选择', 'SeedsUI_placeholder_select'),
    allowClear: allowClear,
    ricon: /*#__PURE__*/React.createElement("i", {
      className: "ricon icon shape-arrow-right sm",
      style: {
        marginRight: '4px'
      }
    })
  }), "\u2014", /*#__PURE__*/React.createElement(Combo, {
    portal: portal,
    ModalProps: DatePickerModalProps,
    type: type,
    value: endDate,
    disabled: disabledEnd
    // min={Array.isArray(value) && value.length === 2 ? value[0] : undefined}
    // onError={onError}
    ,
    onBeforeChange: function onBeforeChange(argEndDate) {
      var newEndDate = argEndDate || null;
      if (_onBeforeChange) {
        return _onBeforeChange(startDate || newEndDate ? [startDate, newEndDate] : null);
      }
    },
    onChange: function onChange(argEndDate) {
      var newEndDate = argEndDate || null;
      if (_onChange) _onChange(startDate || newEndDate ? [startDate, newEndDate] : null);
    },
    placeholder: locale('请选择', 'SeedsUI_placeholder_select'),
    allowClear: allowClear,
    ricon: /*#__PURE__*/React.createElement("i", {
      className: "ricon icon shape-arrow-right sm",
      style: {
        marginRight: '4px'
      }
    })
  }));
}
